! ############################################################
!            Satellite Data Simulation Unit v2
!                     -  convolv_radar -
!
! This subroutine applies beam convolution to radar echo.
! The output file will have the same name as the original 
! except that the extention ".bin" is replaced by ".fov.bin". 
! Note that spatial sampling (or grid dimension and interval) 
! remains unchanged.
!
!              Updated from convolv-fov.f by H. M. (May, 2009)
!
 Subroutine convolv_radar
   Use MAINparameters
   Use BMCVparameters
   Implicit NONE
!
!
! Local variables
!
   Real :: radout
   Real :: FWHMx, FWHMy
   Integer :: nx, ny, nz, nf
!
   allocate ( radinp(ngridx,ngridy) )
!
   print *, ' --- Radar FOV convolution --- '
!
   Do nf = 1 , mxfreq_radar
!
      FWHMx = fov_ct_radar(nf)
      FWHMy = fov_dt_radar(nf)
!
      Do nz = 1, nlyr
!
! Reflectivity
!
         radinp = 10.**(dBZ_out(nf,:,:,nz)*.1)
         Do nx = 1 , ngridx
            Do ny = 1 , ngridy
!
! Bug fixed (the dBZ_out array has been put in the right order)
! for v2.1.1
!
               Call fov(nx,ny,FWHMx,FWHMy,radout)
               If (radout > 0.) then
                  dBZ_out(nf,nx,ny,nz) = 10.*log10(radout)
               Else
                  dBZ_out(nf,nx,ny,nz) = -999.
               End If
!
            End do
         End do
!
      End do

!
! Path-integrated attenuation
!
      radinp = 10.**(-0.1*PIA_out(:,:,nf))
      Do nx = 1 , ngridx
         Do ny = 1 , ngridy
!
            Call fov(nx,ny,FWHMx,FWHMy,radout)
!
! Bug fixed (the PIA_out array has been put in the right order)
! for v2.1.1
!
            If (radout > 0.) then
               PIA_out(nf,nx,ny) = -10.*log10(radout)
            Else
               PIA_out(nf,nx,ny) = -999.
            End If
!
         End do
      End do
!
   End do
!
   deallocate ( radinp )
!
   Return
 End Subroutine convolv_radar
